from celery.utils.log import get_task_logger
from storage import UploadedEntity

from portal import storage
from portal.async_celery import celery_app, submission_processor
from portal.service.general import find_course, find_project, find_submission, write_entity

log = get_task_logger(__name__)


@celery_app.task(name='upload-submission-to-storage')
def process_submission(new_submission_id: str, file_params: dict):
    new_submission = find_submission(new_submission_id)
    processor = submission_processor.SubmissionProcessor(new_submission, file_params)
    processor.process_submission()


@celery_app.task(name='upload-results-to-storage')
def upload_results_to_storage(new_submission_id: str, path: str):
    path = str(path)
    new_submission = find_submission(new_submission_id)
    file_params = dict(source=dict(url=path, type='zip'))
    processor = submission_processor.SubmissionProcessor(new_submission, file_params)
    processor.upload_result(path=path)


@celery_app.task(name='clone-submission-files')
def clone_submission_files(source_id: str, target_id: str):
    source = find_submission(source_id)
    target = find_submission(target_id)
    processor = submission_processor.SubmissionProcessor(source)
    processor.clone(target)


@celery_app.task(name='start-processing-submission')
def start_processing_submission(submission_id: str, submission_params):
    submission = find_submission(submission_id)
    processor = submission_processor.SubmissionProcessor(submission, submission_params)
    processor.send_to_worker()


@celery_app.task(name='update-project-test-files')
def update_project_test_files(course_id: str, project_id: str):
    log.info(f"[ASYNC] Updating test files for project: {project_id}")
    course = find_course(course_id)
    project = find_project(course, project_id)
    params = {
        'source': {
            'type': 'git',
            'url': project.config.test_files_source
        }
    }
    updated_entity: UploadedEntity = storage.test_files.update(entity_id=project.id, **params)
    project.config.test_files_commit_hash = updated_entity.version
    write_entity(project)
