import logging
import secrets

from portal.database.models import Secret
from portal.service import general
from portal.service.general import delete_entity, find_secret, write_entity

log = logging.getLogger(__name__)


def __set_secret_data(secret: Secret, data: dict):
    return general.update_entity(secret, data, allowed=['name', 'expires_at'])


def create_secret(client, **data):
    value = secrets.token_urlsafe(64)
    secret = Secret(name=data['name'], value=value)
    client.secrets.append(secret)
    __set_secret_data(secret, data)
    log.info(f"[CREATE] Secret({secret.id}): {secret}")
    return secret, value


def delete_secret(client, sid):
    secret = find_secret(client, sid)
    log.info(f"[DELETE] Secret({secret.id}): {secret}")
    delete_entity(secret)
